summaryrefslogtreecommitdiffstats
path: root/vendor/github.com/blevesearch/bleve/mapping/index.go
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/github.com/blevesearch/bleve/mapping/index.go')
-rw-r--r--vendor/github.com/blevesearch/bleve/mapping/index.go7
1 files changed, 6 insertions, 1 deletions
diff --git a/vendor/github.com/blevesearch/bleve/mapping/index.go b/vendor/github.com/blevesearch/bleve/mapping/index.go
index 736e030b80..86100cfa86 100644
--- a/vendor/github.com/blevesearch/bleve/mapping/index.go
+++ b/vendor/github.com/blevesearch/bleve/mapping/index.go
@@ -289,7 +289,12 @@ func (im *IndexMappingImpl) UnmarshalJSON(data []byte) error {
}
func (im *IndexMappingImpl) determineType(data interface{}) string {
- // first see if the object implements Classifier
+ // first see if the object implements bleveClassifier
+ bleveClassifier, ok := data.(bleveClassifier)
+ if ok {
+ return bleveClassifier.BleveType()
+ }
+ // next see if the object implements Classifier
classifier, ok := data.(Classifier)
if ok {
return classifier.Type()